@@ -12,6 +12,7 @@
 namespace ArchiveMailAgentUtil
 {
 static QString archivePattern = QStringLiteral("ArchiveMailCollection %1");
-Q_REQUIRED_RESULT QDate diffDate(ArchiveMailInfo *info);
-Q_REQUIRED_RESULT bool needToArchive(ArchiveMailInfo *info);
+[[nodiscard]] QDate diffDate(ArchiveMailInfo *info);
+[[nodiscard]] bool needToArchive(ArchiveMailInfo *info);
+[[nodiscard]] bool timeIsInRange(const QList<int> &range, const QTime &time);
 }
