@@ -7,8 +7,9 @@
 
 #include "filterlogdialog.h"
 #include "mailfilterpurposemenuwidget.h"
-#include <KPIMTextEdit/PlainTextEditorWidget>
 #include <MailCommon/FilterLog>
+#include <PimCommon/PurposeMenuMessageWidget>
+#include <TextCustomEditor/PlainTextEditorWidget>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -60,17 +61,21 @@ FilterLogDialog::FilterLogDialog(QWidget *parent)
     pageVBoxLayout->setContentsMargins({});
     mainLayout->addWidget(page);
 
-    mTextEdit = new KPIMTextEdit::PlainTextEditorWidget(new FilterLogTextEdit(this), page);
+    auto purposeMenuMessageWidget = new PimCommon::PurposeMenuMessageWidget(this);
+    pageVBoxLayout->addWidget(purposeMenuMessageWidget);
+
+    mTextEdit = new TextCustomEditor::PlainTextEditorWidget(new FilterLogTextEdit(this), page);
     pageVBoxLayout->addWidget(mTextEdit);
 
     mTextEdit->setReadOnly(true);
     mTextEdit->editor()->setWordWrapMode(QTextOption::NoWrap);
     const QStringList logEntries = FilterLog::instance()->logEntries();
-    for (const QString &str : logEntries) {
-        mTextEdit->editor()->appendHtml(str);
-    }
+    const QString log = logEntries.join(QStringLiteral("<br>"));
+    mTextEdit->editor()->appendHtml(log);
 
     auto purposeMenu = new MailfilterPurposeMenuWidget(this, this);
+    connect(purposeMenu, &MailfilterPurposeMenuWidget::shareError, purposeMenuMessageWidget, &PimCommon::PurposeMenuMessageWidget::slotShareError);
+    connect(purposeMenu, &MailfilterPurposeMenuWidget::shareSuccess, purposeMenuMessageWidget, &PimCommon::PurposeMenuMessageWidget::slotShareSuccess);
     auto mShareButton = new QPushButton(i18n("Share..."), this);
     mShareButton->setMenu(purposeMenu->menu());
     mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
@@ -93,12 +98,12 @@ FilterLogDialog::FilterLogDialog(QWidget *parent)
     mLogDetailsBox->setEnabled(mLogActiveBox->isChecked());
     connect(mLogActiveBox, &QCheckBox::toggled, mLogDetailsBox, &QGroupBox::setEnabled);
 
-    mLogPatternDescBox = new QCheckBox(i18n("Log pattern description"));
+    mLogPatternDescBox = new QCheckBox(i18n("Log pattern description"), mLogDetailsBox);
     layout->addWidget(mLogPatternDescBox);
     mLogPatternDescBox->setChecked(FilterLog::instance()->isContentTypeEnabled(FilterLog::PatternDescription));
     connect(mLogPatternDescBox, &QCheckBox::clicked, this, &FilterLogDialog::slotChangeLogDetail);
 
-    mLogRuleEvaluationBox = new QCheckBox(i18n("Log filter &rule evaluation"));
+    mLogRuleEvaluationBox = new QCheckBox(i18n("Log filter &rule evaluation"), mLogDetailsBox);
     layout->addWidget(mLogRuleEvaluationBox);
     mLogRuleEvaluationBox->setChecked(FilterLog::instance()->isContentTypeEnabled(FilterLog::RuleResult));
     connect(mLogRuleEvaluationBox, &QCheckBox::clicked, this, &FilterLogDialog::slotChangeLogDetail);
@@ -110,24 +115,24 @@ FilterLogDialog::FilterLogDialog(QWidget *parent)
              "feedback about the result of the evaluation of all rules "
              "of a single filter will be given."));
 
-    mLogPatternResultBox = new QCheckBox(i18n("Log filter pattern evaluation"));
+    mLogPatternResultBox = new QCheckBox(i18n("Log filter pattern evaluation"), mLogDetailsBox);
     layout->addWidget(mLogPatternResultBox);
     mLogPatternResultBox->setChecked(FilterLog::instance()->isContentTypeEnabled(FilterLog::PatternResult));
     connect(mLogPatternResultBox, &QCheckBox::clicked, this, &FilterLogDialog::slotChangeLogDetail);
 
-    mLogFilterActionBox = new QCheckBox(i18n("Log filter actions"));
+    mLogFilterActionBox = new QCheckBox(i18n("Log filter actions"), mLogDetailsBox);
     layout->addWidget(mLogFilterActionBox);
     mLogFilterActionBox->setChecked(FilterLog::instance()->isContentTypeEnabled(FilterLog::AppliedAction));
     connect(mLogFilterActionBox, &QCheckBox::clicked, this, &FilterLogDialog::slotChangeLogDetail);
 
-    auto hbox = new QWidget(page);
+    auto hboxWidget = new QWidget(page);
     auto hboxHBoxLayout = new QHBoxLayout;
-    hbox->setLayout(hboxHBoxLayout);
+    hboxWidget->setLayout(hboxHBoxLayout);
     hboxHBoxLayout->setContentsMargins({});
-    pageVBoxLayout->addWidget(hbox);
-    auto logSizeLab = new QLabel(i18n("Log size limit:"), hbox);
+    pageVBoxLayout->addWidget(hboxWidget);
+    auto logSizeLab = new QLabel(i18n("Log size limit:"), hboxWidget);
     hboxHBoxLayout->addWidget(logSizeLab);
-    mLogMemLimitSpin = new QSpinBox(hbox);
+    mLogMemLimitSpin = new QSpinBox(hboxWidget);
     hboxHBoxLayout->addWidget(mLogMemLimitSpin, 1);
     mLogMemLimitSpin->setMinimum(1);
     mLogMemLimitSpin->setMaximum(1024 * 256); // 256 MB
@@ -154,7 +159,7 @@ FilterLogDialog::FilterLogDialog(QWidget *parent)
 
     connect(mUser1Button, &QPushButton::clicked, this, &FilterLogDialog::slotUser1);
     connect(mUser2Button, &QPushButton::clicked, this, &FilterLogDialog::slotUser2);
-    connect(mTextEdit->editor(), &KPIMTextEdit::PlainTextEditor::textChanged, this, &FilterLogDialog::slotTextChanged);
+    connect(mTextEdit->editor(), &TextCustomEditor::PlainTextEditor::textChanged, this, &FilterLogDialog::slotTextChanged);
 
     slotTextChanged();
     readConfig();
@@ -171,7 +176,7 @@ void FilterLogDialog::slotTextChanged()
 void FilterLogDialog::readConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group(config, "FilterLog");
+    KConfigGroup group(config, QStringLiteral("FilterLog"));
     const bool isEnabled = group.readEntry("Enabled", false);
     const bool isLogPatternDescription = group.readEntry("LogPatternDescription", false);
     const bool isLogRuleResult = group.readEntry("LogRuleResult", false);
@@ -198,7 +203,7 @@ void FilterLogDialog::readConfig()
         FilterLog::instance()->setMaxLogSize(maxLogSize);
     }
 
-    KConfigGroup geometryGroup(config, "Geometry");
+    KConfigGroup geometryGroup(config, QStringLiteral("Geometry"));
     const QSize size = geometryGroup.readEntry("filterLogSize", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -209,8 +214,8 @@ void FilterLogDialog::readConfig()
 
 FilterLogDialog::~FilterLogDialog()
 {
-    disconnect(mTextEdit->editor(), &KPIMTextEdit::PlainTextEditor::textChanged, this, &FilterLogDialog::slotTextChanged);
-    KConfigGroup myGroup(KSharedConfig::openConfig(), "Geometry");
+    disconnect(mTextEdit->editor(), &TextCustomEditor::PlainTextEditor::textChanged, this, &FilterLogDialog::slotTextChanged);
+    KConfigGroup myGroup(KSharedConfig::openConfig(), QStringLiteral("Geometry"));
     myGroup.writeEntry("filterLogSize", size());
     myGroup.sync();
 }
@@ -222,7 +227,7 @@ void FilterLogDialog::writeConfig()
     }
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group(config, "FilterLog");
+    KConfigGroup group(config, QStringLiteral("FilterLog"));
     group.writeEntry("Enabled", FilterLog::instance()->isLogging());
     group.writeEntry("LogPatternDescription", FilterLog::instance()->isContentTypeEnabled(FilterLog::PatternDescription));
     group.writeEntry("LogRuleResult", FilterLog::instance()->isContentTypeEnabled(FilterLog::RuleResult));
@@ -322,14 +327,14 @@ void FilterLogDialog::slotUser2()
                                     "\"%2\" is the detailed error description.",
                                     fileName.at(0),
                                     QString::fromLocal8Bit(strerror(errno))),
-                               i18n("KMail Error"));
+                               i18nc("@title:window", "KMail Error"));
         }
     }
     delete fdlg;
 }
 
 FilterLogTextEdit::FilterLogTextEdit(QWidget *parent)
-    : KPIMTextEdit::PlainTextEditor(parent)
+    : TextCustomEditor::PlainTextEditor(parent)
 {
 }
 
@@ -344,3 +349,5 @@ void FilterLogTextEdit::addExtraMenuEntry(QMenu *menu, QPoint pos)
         menu->addAction(clearAllAction);
     }
 }
+
+#include "moc_filterlogdialog.cpp"
