@@ -33,7 +33,7 @@ bool MailMergeManager::itemRemoved(Akonadi::Item::Id id)
 {
     // TODO remove id.
     // TODO
-    //    if (mConfig->hasGroup(SendLaterUtil::sendLaterPattern().arg(id))) {
+    //    if (mConfig->hasGroup(QLatin1String(SendLaterUtil::sendLaterPattern().arg(id)))) {
     //        removeInfo(id);
     //        mConfig->reparseConfiguration();
     //        Q_EMIT needUpdateConfigDialogBox();
@@ -41,3 +41,5 @@ bool MailMergeManager::itemRemoved(Akonadi::Item::Id id)
     //    }
     return false;
 }
+
+#include "moc_mailmergemanager.cpp"
