@@ -18,27 +18,14 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <QApplication>
 #include <QCommandLineParser>
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("ktnef");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("ktnef"));
     KCrash::initialize();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("ktnef"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("ktnefrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("ktnefui.rc"));
-    migrate.migrate();
-#endif
 
     KAboutData aboutData(QStringLiteral("ktnef"),
                          i18n("KTnef"),
