@@ -16,7 +16,7 @@ public:
     explicit TaskAttribute(Akonadi::Item::Id id);
     ~TaskAttribute() override;
 
-    Q_REQUIRED_RESULT QByteArray type() const override;
+    [[nodiscard]] QByteArray type() const override;
 
     TaskAttribute *clone() const override;
 
@@ -25,7 +25,7 @@ public:
     void deserialize(const QByteArray &data) override;
 
     void setTaskId(Akonadi::Item::Id id);
-    Q_REQUIRED_RESULT Akonadi::Item::Id taskId() const;
+    [[nodiscard]] Akonadi::Item::Id taskId() const;
 
 private:
     Akonadi::Item::Id mId = {-1};
