@@ -35,7 +35,7 @@ using namespace MailCommon;
 CollectionMailingListPage::CollectionMailingListPage(QWidget *parent)
     : CollectionPropertiesPage(parent)
 {
-    setObjectName(QStringLiteral("KMail::CollectionMailingListPage"));
+    setObjectName(QLatin1StringView("KMail::CollectionMailingListPage"));
     setPageTitle(i18nc("@title:tab Mailing list settings for a folder.", "Mailing List"));
 }
 
