@@ -21,7 +21,7 @@ public:
     explicit CollectionQuotaPage(QWidget *parent = nullptr);
     void load(const Akonadi::Collection &col) override;
     void save(Akonadi::Collection &col) override;
-    Q_REQUIRED_RESULT bool canHandle(const Akonadi::Collection &collection) const override;
+    [[nodiscard]] bool canHandle(const Akonadi::Collection &collection) const override;
 
 private:
     void init();
