@@ -30,7 +30,7 @@ using namespace MailCommon;
 CollectionViewPage::CollectionViewPage(QWidget *parent)
     : CollectionPropertiesPage(parent)
 {
-    setObjectName(QStringLiteral("KMail::CollectionViewPage"));
+    setObjectName(QLatin1StringView("KMail::CollectionViewPage"));
     setPageTitle(i18nc("@title:tab View settings for a folder.", "View"));
 }
 
