@@ -44,7 +44,6 @@ using PimCommon::RecentAddresses;
 #include <QRegularExpressionValidator>
 #include <QScrollArea>
 #include <QStringEncoder>
-#include <QTextCodec>
 #include <QVBoxLayout>
 
 #include <PimCommonAkonadi/CompletionConfigureDialog>
@@ -319,7 +318,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
 #if KDEPIM_ENTERPRISE_BUILD
     // "Warn if too many recipients" checkbox/spinbox
     mRecipientCheck = new QCheckBox(KMailSettings::self()->tooManyRecipientsItem()->label(), this);
-    mRecipientCheck->setObjectName(QStringLiteral("kcfg_TooManyRecipients"));
+    mRecipientCheck->setObjectName(QLatin1StringView("kcfg_TooManyRecipients"));
     helpText = i18n(KMailSettings::self()->tooManyRecipientsItem()->whatsThis().toUtf8().constData());
     mRecipientCheck->setWhatsThis(helpText);
     mRecipientCheck->setToolTip(i18n("Warn if too many recipients are specified"));
@@ -329,7 +328,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mRecipientSpin->setMinimum(1 /*min*/);
     mRecipientSpin->setSingleStep(1 /*step*/);
     mRecipientSpin->setValue(5 /*init*/);
-    mRecipientSpin->setObjectName(QStringLiteral("kcfg_RecipientThreshold"));
+    mRecipientSpin->setObjectName(QLatin1StringView("kcfg_RecipientThreshold"));
     mRecipientSpin->setEnabled(false);
     helpText = i18n(KMailSettings::self()->recipientThresholdItem()->whatsThis().toUtf8().constData());
     mRecipientSpin->setWhatsThis(helpText);
@@ -424,7 +423,7 @@ ComposerPageGeneralTab::ComposerPageGeneralTab(QWidget *parent)
     mAutoSave->setMinimum(0);
     mAutoSave->setSingleStep(1);
     mAutoSave->setValue(1);
-    mAutoSave->setObjectName(QStringLiteral("kcfg_AutosaveInterval"));
+    mAutoSave->setObjectName(QLatin1StringView("kcfg_AutosaveInterval"));
     mAutoSave->setSpecialValueText(i18n("No autosave"));
     mAutoSave->setSuffix(ki18ncp("Interval suffix", " minute", " minutes"));
 
@@ -768,7 +767,7 @@ void ComposerPageCharsetTab::slotVerifyCharset(QString &charset)
         charset = QStringLiteral("us-ascii");
         return;
     } else if (charsetLower == QLatin1String("locale")) {
-        charset = QStringLiteral("%1 (locale)").arg(QString::fromLatin1(kmkernel->networkCodec()->name()).toLower());
+        charset = QString::fromUtf8(QStringEncoder(QStringEncoder::Utf8).name());
         return;
     }
 
@@ -791,7 +790,7 @@ void ComposerPageCharsetTab::doLoadOther()
     QStringList::Iterator end(charsets.end());
     for (QStringList::Iterator it = charsets.begin(); it != end; ++it) {
         if ((*it) == QLatin1String("locale")) {
-            QByteArray cset = kmkernel->networkCodec()->name();
+            QByteArray cset = QStringEncoder(QStringEncoder::Utf8).name();
             cset = cset.toLower();
             (*it) = QStringLiteral("%1 (locale)").arg(QString::fromLatin1(cset));
         }
@@ -1084,17 +1083,6 @@ ComposerPageAttachmentsTab::ComposerPageAttachmentsTab(QWidget *parent)
 {
     auto vlay = new QVBoxLayout(this);
 
-    // "Outlook compatible attachment naming" check box
-    mOutlookCompatibleCheck = new QCheckBox(i18n("Outlook-compatible attachment naming"), this);
-    mOutlookCompatibleCheck->setChecked(false);
-    mOutlookCompatibleCheck->setToolTip(
-        i18n("Turn this option on to make Outlook(tm) understand attachment names "
-             "containing non-English characters"));
-    connect(mOutlookCompatibleCheck, &QCheckBox::stateChanged, this, &ConfigModuleTab::slotEmitChanged);
-    connect(mOutlookCompatibleCheck, &QAbstractButton::clicked, this, &ComposerPageAttachmentsTab::slotOutlookCompatibleClicked);
-    vlay->addWidget(mOutlookCompatibleCheck);
-    vlay->addSpacing(5);
-
     // "Enable detection of missing attachments" check box
     mMissingAttachmentDetectionCheck = new QCheckBox(i18n("E&nable detection of missing attachments"), this);
     mMissingAttachmentDetectionCheck->setChecked(true);
@@ -1139,7 +1127,6 @@ ComposerPageAttachmentsTab::ComposerPageAttachmentsTab(QWidget *parent)
 
 void ComposerPageAttachmentsTab::doLoadFromGlobalSettings()
 {
-    loadWidget(mOutlookCompatibleCheck, MessageComposer::MessageComposerSettings::self()->outlookCompatibleAttachmentsItem());
     loadWidget(mMissingAttachmentDetectionCheck, KMailSettings::self()->showForgottenAttachmentWarningItem());
     loadWidget(mAttachWordsListEditor, KMailSettings::self()->attachmentKeywordsItem());
     const int maximumAttachmentSize(MessageCore::MessageCoreSettings::self()->maximumAttachmentSize());
@@ -1148,30 +1135,13 @@ void ComposerPageAttachmentsTab::doLoadFromGlobalSettings()
 
 void ComposerPageAttachmentsTab::save()
 {
-    saveCheckBox(mOutlookCompatibleCheck, MessageComposer::MessageComposerSettings::self()->outlookCompatibleAttachmentsItem());
     saveCheckBox(mMissingAttachmentDetectionCheck, KMailSettings::self()->showForgottenAttachmentWarningItem());
     saveSimpleStringListEditor(mAttachWordsListEditor, KMailSettings::self()->attachmentKeywordsItem());
 
-    KMime::setUseOutlookAttachmentEncoding(mOutlookCompatibleCheck->isChecked());
     const int maximumAttachmentSize(mMaximumAttachmentSize->value());
     MessageCore::MessageCoreSettings::self()->setMaximumAttachmentSize(maximumAttachmentSize == -1 ? -1 : maximumAttachmentSize * 1024);
 }
 
-void ComposerPageAttachmentsTab::slotOutlookCompatibleClicked()
-{
-    if (mOutlookCompatibleCheck->isChecked()) {
-        KMessageBox::information(nullptr,
-                                 i18n("You have chosen to "
-                                      "encode attachment names containing non-English characters in a way that "
-                                      "is understood by Outlook(tm) and other mail clients that do not "
-                                      "support standard-compliant encoded attachment names.\n"
-                                      "Note that KMail may create non-standard compliant messages, "
-                                      "and consequently it is possible that your messages will not be "
-                                      "understood by standard-compliant mail clients; so, unless you have no "
-                                      "other choice, you should not enable this option."));
-    }
-}
-
 ComposerPageAutoCorrectionTab::ComposerPageAutoCorrectionTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
