@@ -11,7 +11,6 @@
 #pragma once
 
 #include "configmodule.h"
-#include "kcmutils_version.h"
 #include "kmail_export.h"
 class QTabWidget;
 class ConfigureDialog;
@@ -68,11 +67,7 @@ class KMAIL_EXPORT ConfigModuleWithTabs : public ConfigModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit ConfigModuleWithTabs(QWidget *parent = nullptr, const QVariantList &args = {});
-#else
-    explicit ConfigModuleWithTabs(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit ConfigModuleWithTabs(QObject *parent, const KPluginMetaData &data);
     ~ConfigModuleWithTabs() override = default;
 
     // don't reimplement any of those methods
@@ -81,11 +76,6 @@ public:
     void defaults() override;
 
 protected:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    void showEvent(QShowEvent *event) override;
-#else
-#pragma "NEED TO PORT TO QT6";
-#endif
     void addTab(ConfigModuleTab *tab, const QString &title);
 
 private:
