@@ -18,7 +18,7 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <QHBoxLayout>
 
 #ifdef WITH_KUSERFEEDBACK
-#include <KUserFeedbackQt6/FeedbackConfigWidget>
+#include <KUserFeedback/FeedbackConfigWidget>
 #endif
 
 using namespace MailCommon;
