@@ -519,12 +519,6 @@ private:
      */
     [[nodiscard]] bool queryClose() override;
 
-    /**
-     * Turn encryption on/off. If setByUser is true then a message box is shown
-     * in case encryption isn't possible.
-     */
-    void setEncryption(bool encrypt, bool setByUser = false);
-
     /**
      * Turn signing on/off. If setByUser is true then a message box is shown
      * in case signing isn't possible.
@@ -593,7 +587,7 @@ private:
 
     std::unique_ptr<Kleo::KeyResolverCore> fillKeyResolver();
     void runKeyResolver();
-    void annotateRecipientEditorLineWithCrpytoInfo(MessageComposer::RecipientLineNG *line, bool autocryptKey, bool gossipKey);
+    void annotateRecipientEditorLineWithCryptoInfo(MessageComposer::RecipientLineNG *line, bool autocryptKey, bool gossipKey);
 
     Akonadi::Collection mCollectionForNewMessage;
     QMap<QByteArray, QString> mExtraHeaders;
