@@ -17,12 +17,13 @@ PotentialPhishingEmailWarning::PotentialPhishingEmailWarning(QWidget *parent)
     setCloseButtonVisible(true);
     setMessageType(Warning);
     setWordWrap(true);
+    setPosition(KMessageWidget::Header);
 
     setText(i18n("Found potential phishing email addresses <a href=\"phishingdetails\">(details...)</a>"));
 
     connect(this, &KMessageWidget::linkActivated, this, &PotentialPhishingEmailWarning::slotShowDetails);
     auto action = new QAction(i18n("Send Now"), this);
-    action->setObjectName(QStringLiteral("sendnow"));
+    action->setObjectName(QLatin1StringView("sendnow"));
     connect(action, &QAction::triggered, this, &PotentialPhishingEmailWarning::sendNow);
     addAction(action);
 }
