@@ -13,6 +13,7 @@
 AttachmentAddedFromExternalWarning::AttachmentAddedFromExternalWarning(QWidget *parent)
     : KMessageWidget(parent)
 {
+    setPosition(KMessageWidget::Header);
     setVisible(false);
     setCloseButtonVisible(true);
     setMessageType(Information);
@@ -42,3 +43,5 @@ void AttachmentAddedFromExternalWarning::setAttachmentNames(const QStringList &l
             i18n("These attachments: <ul><li>%1</li></ul> were added externally. Remove them if it's an error.", attachments.join(QLatin1String("</li><li>"))));
     }
 }
+
+#include "moc_attachmentaddedfromexternalwarning.cpp"
