@@ -10,6 +10,7 @@
 IncorrectIdentityFolderWarning::IncorrectIdentityFolderWarning(QWidget *parent)
     : KMessageWidget(parent)
 {
+    setPosition(KMessageWidget::Header);
     setVisible(false);
     setCloseButtonVisible(true);
     setMessageType(Warning);
@@ -92,3 +93,5 @@ void IncorrectIdentityFolderWarning::slotHideAnnimationFinished()
     mIdentityIsInvalid = false;
     mDictionaryIsInvalid = false;
 }
+
+#include "moc_incorrectidentityfolderwarning.cpp"
