@@ -21,8 +21,9 @@ CryptoStateIndicatorWidget::CryptoStateIndicatorWidget(QWidget *parent)
     hbox->setContentsMargins({});
     mSignatureStateIndicator->setAlignment(Qt::AlignHCenter);
     mSignatureStateIndicator->setTextFormat(Qt::PlainText);
+    mSignatureStateIndicator->setContentsMargins(4, 4, 4, 4);
     hbox->addWidget(mSignatureStateIndicator);
-    mSignatureStateIndicator->setObjectName(QStringLiteral("signatureindicator"));
+    mSignatureStateIndicator->setObjectName(QLatin1StringView("signatureindicator"));
     QPalette p(mSignatureStateIndicator->palette());
     p.setColor(QPalette::Window, MessageCore::ColorUtil::self()->pgpSignedTrustedMessageColor());
     p.setColor(QPalette::Text, MessageCore::ColorUtil::self()->pgpSignedTrustedTextColor());
@@ -31,13 +32,14 @@ CryptoStateIndicatorWidget::CryptoStateIndicatorWidget(QWidget *parent)
 
     mEncryptionStateIndicator->setAlignment(Qt::AlignHCenter);
     mEncryptionStateIndicator->setTextFormat(Qt::PlainText);
+    mEncryptionStateIndicator->setContentsMargins(4, 4, 4, 4);
     hbox->addWidget(mEncryptionStateIndicator);
     p = mEncryptionStateIndicator->palette();
     p.setColor(QPalette::Window, MessageCore::ColorUtil::self()->pgpEncryptedMessageColor());
     p.setColor(QPalette::Text, MessageCore::ColorUtil::self()->pgpEncryptedTextColor());
     mEncryptionStateIndicator->setPalette(p);
     mEncryptionStateIndicator->setAutoFillBackground(true);
-    mEncryptionStateIndicator->setObjectName(QStringLiteral("encryptionindicator"));
+    mEncryptionStateIndicator->setObjectName(QLatin1StringView("encryptionindicator"));
     hide();
 }
 
