@@ -135,7 +135,7 @@ void FolderArchiveManager::removeInfo(const QString &instanceName)
 {
     KConfig config(FolderArchive::FolderArchiveUtil::configFileName());
     KConfigGroup group = config.group(FolderArchive::FolderArchiveUtil::groupConfigPattern() + instanceName);
-    group.deleteGroup();
+    group.deleteGroup(QLatin1String());
     config.sync();
 }
 
@@ -165,7 +165,6 @@ void FolderArchiveManager::moveDone()
                          QString(),
                          i18n("Messages archived"),
                          QStringLiteral("kmail"),
-                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("kmail2"));
     nextJob();
@@ -177,7 +176,6 @@ void FolderArchiveManager::moveFailed(const QString &msg)
                          QString(),
                          msg,
                          QStringLiteral("kmail"),
-                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("kmail2"));
     nextJob();
@@ -203,3 +201,5 @@ void FolderArchiveManager::reloadConfig()
 {
     load();
 }
+
+#include "moc_folderarchivemanager.cpp"
