@@ -13,6 +13,12 @@ class HistoryClosedReaderManagerTest : public QObject
 public:
     explicit HistoryClosedReaderManagerTest(QObject *parent = nullptr);
     ~HistoryClosedReaderManagerTest() override = default;
+
 private Q_SLOTS:
     void shouldHaveDefaultValues();
+    void shouldAddValues();
+    void shouldClear();
+    void shouldRemoveValue();
+    void shouldEmitSignal();
+    void shouldAssignMaxValues();
 };
