@@ -19,12 +19,18 @@ public:
 
     void addInfo(const HistoryClosedReaderInfo &info);
 
-    [[nodiscard]] HistoryClosedReaderInfo lastInfo() const;
+    [[nodiscard]] HistoryClosedReaderInfo lastInfo();
 
     void clear();
 
     [[nodiscard]] bool isEmpty() const;
 
+    void removeItem(Akonadi::Item::Id id);
+
+    [[nodiscard]] int count() const;
+
+    [[nodiscard]] QList<HistoryClosedReaderInfo> closedReaderInfos() const;
+
 Q_SIGNALS:
     void historyClosedReaderChanged();
 
