@@ -11,10 +11,10 @@
 
 #include "newidentitydialog.h"
 
-#include <KIdentityManagement/IdentityManager>
+#include <KIdentityManagementCore/IdentityManager>
+#include <KLineEditEventHandler>
 #include <KLocalizedString>
 #include <KSeparator>
-#include <Libkdepim/LineEditCatchReturnKey>
 #include <PimCommon/PimUtil>
 #include <QComboBox>
 #include <QLineEdit>
@@ -31,7 +31,7 @@
 
 using namespace KMail;
 
-NewIdentityDialog::NewIdentityDialog(KIdentityManagement::IdentityManager *manager, QWidget *parent)
+NewIdentityDialog::NewIdentityDialog(KIdentityManagementCore::IdentityManager *manager, QWidget *parent)
     : QDialog(parent)
     , mIdentityManager(manager)
 {
@@ -57,7 +57,7 @@ NewIdentityDialog::NewIdentityDialog(KIdentityManagement::IdentityManager *manag
     mLineEdit = new QLineEdit(page);
     mLineEdit->setFocus();
     mLineEdit->setClearButtonEnabled(true);
-    new KPIM::LineEditCatchReturnKey(mLineEdit, this);
+    KLineEditEventHandler::catchReturnKey(mLineEdit);
     auto l = new QLabel(i18n("&New identity:"), page);
     l->setBuddy(mLineEdit);
     hlay->addWidget(l);
@@ -145,3 +145,5 @@ QString NewIdentityDialog::duplicateIdentity() const
 {
     return mComboBox->currentText();
 }
+
+#include "moc_newidentitydialog.cpp"
