@@ -35,7 +35,6 @@ using namespace KMail;
 
 KMailPart::KMailPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData &data, const QVariantList &)
     : KParts::ReadOnlyPart(parent, data)
-    , mParentWidget(parentWidget)
 {
     setComponentName(QStringLiteral("kmail2"), i18n("KMail2"));
     // local, do the init
@@ -56,10 +55,10 @@ KMailPart::KMailPart(QWidget *parentWidget, QObject *parent, const KPluginMetaDa
     // create a canvas to insert our widget
     auto canvas = new QWidget(parentWidget);
     canvas->setFocusPolicy(Qt::ClickFocus);
-    canvas->setObjectName(QStringLiteral("canvas"));
+    canvas->setObjectName(QLatin1StringView("canvas"));
     setWidget(canvas);
     mainWidget = new KMMainWidget(canvas, this, actionCollection(), KSharedConfig::openConfig());
-    mainWidget->setObjectName(QStringLiteral("partmainwidget"));
+    mainWidget->setObjectName(QLatin1StringView("partmainwidget"));
     auto topLayout = new QVBoxLayout(canvas);
     topLayout->addWidget(mainWidget);
     topLayout->setContentsMargins({});
