@@ -8,7 +8,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
 #include <KViewStateMaintainer>
 namespace Akonadi
@@ -28,11 +27,7 @@ class KCMKMailSummary : public KCModule
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMKMailSummary(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMKMailSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMKMailSummary(QObject *parent, const KPluginMetaData &data);
 
     void load() override;
     void save() override;
