@@ -45,6 +45,7 @@
 #include <QIcon>
 #include <QMenu>
 
+#include "folderarchive/folderarchivemanager.h"
 #include <Akonadi/Collection>
 #include <Akonadi/EntityAnnotationsAttribute>
 #include <Akonadi/StandardMailActionManager>
@@ -81,6 +82,7 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     , mNewMessageFromTemplateAction(new QAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New Message From &Template"), this))
     , mWebShortcutMenuManager(new KIO::KUriFilterSearchProviderActions(this))
     , mExportToPdfAction(new QAction(QIcon::fromTheme(QStringLiteral("application-pdf")), i18n("Export to PDF..."), this))
+    , mArchiveMessageAction(new QAction(i18nc("@action:inmenu", "Archive Message"), this))
 
 {
     ac->addAction(QStringLiteral("message_reply_menu"), mReplyActionMenu);
@@ -183,6 +185,9 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     ac->addAction(QStringLiteral("file_export_pdf"), mExportToPdfAction);
     connect(mExportToPdfAction, &QAction::triggered, this, &MessageActions::slotExportToPdf);
 
+    ac->addAction(QStringLiteral("archive_message"), mArchiveMessageAction);
+    connect(mArchiveMessageAction, &QAction::triggered, this, &MessageActions::slotArchiveMessage);
+
     updateActions();
 }
 
@@ -386,6 +391,7 @@ void MessageActions::updateActions()
         }
     }
     mEditAsNewAction->setEnabled(uniqItem);
+    mArchiveMessageAction->setEnabled(hasPayload);
 }
 
 void MessageActions::slotUpdateActionsFetchDone(KJob *job)
@@ -568,11 +574,7 @@ void MessageActions::slotNoQuoteReplyToMsg()
 void MessageActions::slotRunUrl(QAction *urlAction)
 {
     const QVariant q = urlAction->data();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    if (q.type() == QVariant::Url) {
-#else
     if (q.userType() == QMetaType::QUrl) {
-#endif
         auto job = new KIO::OpenUrlJob(q.toUrl());
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mParent));
         job->start();
@@ -779,6 +781,17 @@ void MessageActions::slotExportToPdf()
     }
 }
 
+void MessageActions::slotArchiveMessage()
+{
+    if (!mCurrentItem.isValid() || !mCurrentItem.parentCollection().isValid()) {
+        return;
+    }
+    Akonadi::Item::List items;
+    items << mCurrentItem;
+    auto resource = CommonKernel->collectionFromId(mCurrentItem.parentCollection().id()).resource();
+    KMKernel::self()->folderArchiveManager()->setArchiveItems(items, resource);
+}
+
 Akonadi::Item MessageActions::currentItem() const
 {
     return mCurrentItem;
@@ -788,3 +801,10 @@ QAction *MessageActions::exportToPdfAction() const
 {
     return mExportToPdfAction;
 }
+
+QAction *MessageActions::archiveMessageAction() const
+{
+    return mArchiveMessageAction;
+}
+
+#include "moc_messageactions.cpp"
