@@ -6,13 +6,9 @@
 
 #pragma once
 #include "kmail_private_export.h"
-#include <KSieveUi/SieveImapPasswordProvider>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
+#include <KSieveCore/SieveImapPasswordProvider>
 #include <qt6keychain/keychain.h>
-#endif
-class KMAILTESTS_TESTS_EXPORT KMSieveImapPasswordProvider : public KSieveUi::SieveImapPasswordProvider
+class KMAILTESTS_TESTS_EXPORT KMSieveImapPasswordProvider : public KSieveCore::SieveImapPasswordProvider
 {
     Q_OBJECT
 public:
