@@ -11,7 +11,7 @@
 #include <Akonadi/Item>
 #include <Akonadi/Tag>
 #include <QDialog>
-#include <QVector>
+#include <QList>
 
 class QListWidget;
 class KActionCollection;
@@ -21,7 +21,7 @@ class KMAILTESTS_TESTS_EXPORT TagSelectDialog : public QDialog
 public:
     explicit TagSelectDialog(QWidget *parent, int numberOfSelectedMessages, const Akonadi::Item &selectedItem);
     ~TagSelectDialog() override;
-    Q_REQUIRED_RESULT Akonadi::Tag::List selectedTag() const;
+    [[nodiscard]] Akonadi::Tag::List selectedTag() const;
 
     void setActionCollection(const QList<KActionCollection *> &actionCollectionList);
 
@@ -36,7 +36,7 @@ private:
     const Akonadi::Item mSelectedItem;
 
     Akonadi::Tag::List mCurrentSelectedTags;
-    QVector<MailCommon::Tag::Ptr> mTagList;
+    QList<MailCommon::Tag::Ptr> mTagList;
     QList<KActionCollection *> mActionCollectionList;
     QListWidget *const mListTag;
 };
